.. nio documentation master file, created by
   sphinx-quickstart on Tue Nov 27 15:15:35 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../README.md

Api Documentation
=================

.. toctree::
   nio
   :maxdepth: 2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
